var back = null;

/**
 * This class encapsules all functions for the front side of the widget.
 */
function Back() {
	this.designTab = null;
	this.alarmTab = null;
	this.currentPrefs = null;
	this.imgPrefix = 'Images/button';
	this.inactiveTabFontColor = '#CCC';
	this._init();
}

/**
 * Init the tab bar and setup event handling.
 */
Back.prototype._init = function() {
	this.createDesignTabButtons();
	this.createAlarmTabButtons();
	$('#tabDesign_active').css('display', 'inline');
	$('#tabAlarm').css('display', 'inline');
	$('#prefsDesign').css('display', 'block');
	$('#prefsDesign').fadeIn('fast');
	this.currentPrefs = 'Design';

	$('#backgroundColor').change(function(event) {
		$('#front').css('background', 'url(Images/Front_' + event.target.value
			+ '.png) no-repeat');
		if (window.widget) {
			widget.setPreferenceForKey(event.target.value, 'background');
		}
	});
};

/**
 * Activate the design tab and show the design panel.
 *
 * @param event: The js event.
 */
Back.prototype.onDesignTabClicked = function(event) {
	back.switchToPrefs('Design');
};

/**
 * Activate the alarm tab and show the alarm panel.
 *
 * @param event: The js event.
 */
Back.prototype.onAlarmTabClicked = function(event) {
	back.switchToPrefs('Alarm');
};

/**
 * 
 *
 * @param :
 */
Back.prototype.switchToPrefs = function(prefs) {
	if (prefs == back.currentPrefs)
		return;

	$('#tab' + back.currentPrefs + '_active').css('display', 'none');
	$('#tab' + back.currentPrefs).css('display', 'inline');
	$('#prefs' + back.currentPrefs).fadeOut('fast');
	$('#prefs' + back.currentPrefs).css('display', 'none');
	
	$('#tab' + prefs).css('display', 'none');
	$('#tab' + prefs + '_active').css('display', 'inline');
	$('#prefs' + prefs).css('display', 'block');
	$('#prefs' + prefs).fadeIn('fast');
	back.currentPrefs = prefs;
};

/**
 * Creates the active and inactive button for the design tab. For both, 
 * css:display is set to none.
 */
Back.prototype.createDesignTabButtons = function() {
	for (i = 0; i < 2; i ++) {
		active = (i == 1) ? '_active' : '';
		$('#tabDesign' + active).css('display', 'none');
		this.designTab = new AppleButton($('#tabDesign' + active).get(0),
			getLocalizedString('Design'), 20,
			this.imgPrefix + 'Left' + active + '_left.png', 
			this.imgPrefix + 'Left' + active + '_left_clicked.png', 10,
			this.imgPrefix + 'Left' + active + '_middle.png', 
			this.imgPrefix + 'Left' + active + '_middle_clicked.png',
			this.imgPrefix + 'Left' + active + '_right.png', 
			this.imgPrefix + 'Left' + active + '_right_clicked.png', 1,
			this.onDesignTabClicked);
		if (!active)
			this.designTab.textElement.style.color = this.inactiveTabFontColor;
	}
};

/**
 * Creates the active and inactive button for the alarm tab. For both, 
 * css:display is set to none.
 */
Back.prototype.createAlarmTabButtons = function(active) {
	for (i = 0; i < 2; i ++) {
		active = (i == 1) ? '_active' : '';
		$('#tabAlarm' + active).css('display', 'none');
		this.alarmTab = new AppleButton($('#tabAlarm' + active).get(0),
			getLocalizedString('Alarm'), 20,
			this.imgPrefix + 'Right' + active + '_left.png', 
			this.imgPrefix + 'Right' + active + '_left_clicked.png', 0,
			this.imgPrefix + 'Right' + active + '_middle.png', 
			this.imgPrefix + 'Right' + active + '_middle_clicked.png',
			this.imgPrefix + 'Right' + active + '_right.png', 
			this.imgPrefix + 'Right' + active + '_right_clicked.png', 10,
			this.onAlarmTabClicked);
		if (!active)
			this.alarmTab.textElement.style.color = this.inactiveTabFontColor;
	}
};
